@@ -1,5 +1,6 @@
 # https://valvedev.info/tools/bspfix/
-# https://developer.valvesoftware.com/wiki/Hl_bs.fgd
+import enum
+
 from ..valve import goldsrc
 
 
@@ -7,8 +8,28 @@ BSP_VERSION = 30
 
 GAMES = ["Half-Life/bshift"]  # Half-Life: Blue Shift
 
-LUMP = goldsrc.LUMP
-# NOTE: different headers?
+
+class LUMP(enum.Enum):
+    PLANES = 0
+    ENTITIES = 1
+    MIP_TEXTURES = 2
+    VERTICES = 3
+    VISIBILITY = 4
+    NODES = 5
+    TEXTURE_INFO = 6
+    FACES = 7
+    LIGHTING = 8
+    CLIP_NODES = 9
+    LEAVES = 10
+    MARK_SURFACES = 11
+    EDGES = 12
+    MODELS = 14
+
+# Known lump changes from Quake II -> GoldSrc:
+# ENTITIES -> PLANES
+# PLANES -> ENTITIES
+
+
 lump_header_address = {LUMP_ID: (4 + i * 8) for i, LUMP_ID in enumerate(LUMP)}
 
 
