@@ -607,7 +607,7 @@ SPECIAL_LUMP_CLASSES = {"ENTITY_PARTITIONS":         {0: EntityPartitions},
                         "ENTITIES":                  {0: shared.Entities},
                         # NOTE: .ent files are handled directly by the RespawnBsp class
                         "PAKFILE":                   {0: shared.PakFile},
-                        # "PHYSICS_COLLIDE":           {0: shared.PhysicsCollide},
+                        "PHYSICS_COLLIDE":           {0: shared.PhysicsCollide},
                         "TEXTURE_DATA_STRING_DATA":  {0: shared.TextureDataStringData}}
 
 GAME_LUMP_CLASSES = {"sprp": {12: lambda raw_lump: GameLump_SPRP(raw_lump, StaticPropv12)}}
